==> haskell-hasql-dynamic-statements-0.3.1.1-159-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-dynamic-statements.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasql-dynamic-statements
version:              0.3.1.1
visibility:           public
id:                   hasql-dynamic-statements-0.3.1.1-E7KKArd9EIrJLGt9u5ZBzG
key:                  hasql-dynamic-statements-0.3.1.1-E7KKArd9EIrJLGt9u5ZBzG
license:              MIT
copyright:            (c) 2019, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-dynamic-statements
synopsis:             Toolkit for constructing Hasql statements dynamically
description:
    This library introduces into the Hasql ecosystem a new abstraction named Snippet,
    which makes it trivial to construct SQL, while injecting values.
    It is intended to be used when the SQL of your statement depends on the parameters,
    that you want to pass in.

abi:                  541009be3229d4878b64d2f58264088d
exposed:              True
exposed-modules:
    Hasql.DynamicStatements.Session Hasql.DynamicStatements.Snippet
    Hasql.DynamicStatements.Statement

hidden-modules:
    Hasql.DynamicStatements.Prelude
    Hasql.DynamicStatements.Snippet.Defs

import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hasql-dynamic-statements-0.3.1.1

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hasql-dynamic-statements-0.3.1.1

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hasql-dynamic-statements-0.3.1.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-dynamic-statements
hs-libraries:         HShasql-dynamic-statements-0.3.1.1-E7KKArd9EIrJLGt9u5ZBzG
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    hasql-1.5.0.4-Fo6LyyW6bINHsaVmAn9a7D
    hasql-implicits-0.1.0.5-KaKrFiBuPPHF8mopaUkJzb
    ptr-0.16.8.7-3ZirkCY9IKoC7ySLuxk4of

haddock-interfaces:
    /usr/share/doc/haskell-hasql-dynamic-statements/html/hasql-dynamic-statements.haddock

haddock-html:         /usr/share/doc/haskell-hasql-dynamic-statements/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-dynamic-statements-0.3.1.1-160-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-dynamic-statements.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasql-dynamic-statements
version:              0.3.1.1
visibility:           public
id:                   hasql-dynamic-statements-0.3.1.1-9GnaSeV9swQHgbyvSgQLVo
key:                  hasql-dynamic-statements-0.3.1.1-9GnaSeV9swQHgbyvSgQLVo
license:              MIT
copyright:            (c) 2019, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-dynamic-statements
synopsis:             Toolkit for constructing Hasql statements dynamically
description:
    This library introduces into the Hasql ecosystem a new abstraction named Snippet,
    which makes it trivial to construct SQL, while injecting values.
    It is intended to be used when the SQL of your statement depends on the parameters,
    that you want to pass in.

abi:                  b0d4ef4075ffe033bb8677328285bb64
exposed:              True
exposed-modules:
    Hasql.DynamicStatements.Session Hasql.DynamicStatements.Snippet
    Hasql.DynamicStatements.Statement

hidden-modules:
    Hasql.DynamicStatements.Prelude
    Hasql.DynamicStatements.Snippet.Defs

import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hasql-dynamic-statements-0.3.1.1

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hasql-dynamic-statements-0.3.1.1

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hasql-dynamic-statements-0.3.1.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-dynamic-statements
hs-libraries:         HShasql-dynamic-statements-0.3.1.1-9GnaSeV9swQHgbyvSgQLVo
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    hasql-1.5.0.4-A7GyNi45PQvSzhjEccd8D
    hasql-implicits-0.1.0.5-9OTPfG5RNAJ1e5jWGWxzYU
    ptr-0.16.8.7-CTLYe9jTzTPafboi0snjj

haddock-interfaces:
    /usr/share/doc/haskell-hasql-dynamic-statements/html/hasql-dynamic-statements.haddock

haddock-html:         /usr/share/doc/haskell-hasql-dynamic-statements/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
